%%

% This is the main file to run QCL.
% To run QCL, type QCL in the MATLAB command window, 
% or open QCL.m with MATLAB editor and press F5.
% The "Main Window" of the program will appear.
% Enter the input parameters and click "Run" button to start the analysis.
%%

clear all
close all

global lambda TEMP DELTA LAMBDA

XY = get(0,'screensize');
font_scale=XY(4)/1200;
fig1 = figure('Position', 0.85*XY);
axis off
set(fig1,'color',[0.9 0.9 0.9])
set(fig1, 'NextPlot', 'add', 'Name', 'QUANTUM CASCADE LASER', 'NumberTitle', 'off','Resize','off');
% set(fig1, 'MenuBar','none');
%%

% When open the project, it will set default data

% Initialization
lambda = 11.2; % x 10^(-6) m
lambda_min = 5; % x 10^(-6) m
lambda_max = 15; % x 10^(-6) m
TEMP = 77; %K
TEMP_min = 1; %K
TEMP_max=350; %K
DELTA = 1.5; % Angstrom
DELTA_min = 0; % Angstrom
DELTA_max = 2; % Angstrom
LAMBDA = 60; %Angstrom
LAMBDA_min = 0; %Angstrom
LAMBDA_max=200; %Angstrom
calc = 1; % if calc == 1, program calculates optimal QCL parameters; 
% if calc == 0, user enters parameters manualy
X = 0.33;
X_min = 0.01;
X_max = 0.4;
K = 44e5; % V / m
K_min = 30e5; % V / m
K_max = 50e5; % V / m
zw0 = 19; % Angstrom
zb1 = 11; % Angstrom
zw1 = 58; % Angstrom
zb2 = 11; % Angstrom
zw2 = 49; % Angstrom
Z_min = 8; % Angstrom
Z_max = 60; % Angstrom
Bmin = 3; % T   
Bmin_min = 1; %T
Bmin_max = 60; %T
Bmax = 60; %T
Bmax_min = 1; %T
Bmax_max = 60; %T
dB = 0.5; % T
%%

% Parameters
panelParameters = uipanel('Title','Parameters',...    
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor', [.1 .3 .5],...
    'TitlePosition','lefttop',...
    'BorderType', 'etchedin',...
    'FontWeight','bold',...
    'FontSize',20*font_scale,...
    'Units','pixels',...
    'Position',[0.02*XY(3) 0.03*XY(4) 0.165*XY(3) 0.8*XY(4)]);
%%

% Opeartional variables
uicontrol('Parent',panelParameters,'Style','text',...
    'String','(1) Operational variables',...        
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor', [.1 .3 .5],...    
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...
    'FontSize',16*font_scale,...
    'Units','pixels',...
    'Position',[0.01*XY(3) 0.73*XY(4) 0.15*XY(3) 0.025*XY(4)]);

% Wavelength
uicontrol('Parent',panelParameters,'Style','text',...
    'String','l =',...
    'BackgroundColor',[.9 .9 .9],...
    'HorizontalAlignment','left',...       
    'FontWeight', 'bold',...
    'FontName', 'symbol',... 
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.05*XY(3) 0.69*XY(4) 0.02*XY(3) 0.025*XY(4)]);   
editlambda = uicontrol('Parent',panelParameters,'Style','edit',...
    'String',lambda,...
    'BackgroundColor','w',...    
    'HorizontalAlignment','right',...    
    'FontWeight', 'bold',...
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.072*XY(3) 0.693*XY(4) 0.04*XY(3) 0.025*XY(4)],...
    'Callback','change_lambda;');
lambda = lambda * 1e-6;
unitlambda = uicontrol('Parent',panelParameters,'Style','text',...
    'String',[181,'m'],...
    'BackgroundColor',[.9 .9 .9],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...    
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.115*XY(3) 0.69*XY(4) 0.02*XY(3) 0.025*XY(4)]);

% Temperature
uicontrol('Parent',panelParameters,'Style','text',...
    'String','T =',...
    'BackgroundColor',[.9 .9 .9],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.05*XY(3) 0.65*XY(4) 0.02*XY(3) 0.025*XY(4)]);   
editT = uicontrol('Parent',panelParameters,'Style','edit',...    
    'String',TEMP,...
    'BackgroundColor','w',...
    'HorizontalAlignment','right',...    
    'FontWeight', 'bold',...   
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.072*XY(3) 0.653*XY(4) 0.04*XY(3) 0.025*XY(4)],...
    'Callback','change_TEMP;');
unitT = uicontrol('Parent',panelParameters,'Style','text',...
    'String','K',...
    'BackgroundColor',[.9 .9 .9],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...    
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.115*XY(3) 0.65*XY(4) 0.02*XY(3) 0.025*XY(4)]);
%%

% IR scattering parameters
uicontrol('Parent',panelParameters,'Style','text',...
    'String','(2) IR parameters',...
    'BackgroundColor',[.9 .9 .9],...    
    'ForegroundColor', [.1 .3 .5],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...
    'FontSize',16*font_scale,...
    'Units','pixels',...
    'Position',[0.01*XY(3) 0.61*XY(4) 0.15*XY(3) 0.025*XY(4)]);

% DELTA
uicontrol('Parent',panelParameters,'Style','text',...
    'String','D =',...
    'BackgroundColor',[.9 .9 .9],...    
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...
    'FontName', 'symbol',...    
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.05*XY(3) 0.57*XY(4) 0.02*XY(3) 0.025*XY(4)]);   
editDELTA = uicontrol('Parent',panelParameters,'Style','edit',...
    'String',DELTA,...
    'BackgroundColor','w',...
    'HorizontalAlignment','right',...    
    'FontWeight', 'bold',...    
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.072*XY(3) 0.575*XY(4) 0.04*XY(3) 0.025*XY(4)],...
    'Callback','change_DELTA;');
unitDELTA = uicontrol('Parent',panelParameters,'Style','text',...
    'String',char(197),...
    'BackgroundColor',[.9 .9 .9],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...    
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.115*XY(3) 0.57*XY(4) 0.02*XY(3) 0.025*XY(4)]);

% LAMBDA
uicontrol('Parent',panelParameters,'Style','text',...
    'String','L =',...
    'BackgroundColor',[.9 .9 .9],... 
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...
    'FontName', 'symbol',...
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.05*XY(3) 0.53*XY(4) 0.02*XY(3) 0.025*XY(4)]);   
editLAMBDA = uicontrol('Parent',panelParameters,'Style','edit',...    
    'String',LAMBDA,...
    'BackgroundColor','w',...
    'HorizontalAlignment','right',...    
    'FontWeight', 'bold',...    
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.072*XY(3) 0.532*XY(4) 0.04*XY(3) 0.025*XY(4)],...
    'Callback','change_LAMBDA;');
unitLAMBDA = uicontrol('Parent',panelParameters,'Style','text',...
    'String',char(197),...
    'BackgroundColor',[.9 .9 .9],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...    
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.115*XY(3) 0.53*XY(4) 0.02*XY(3) 0.025*XY(4)]);
%%

% QCL parameters
uicontrol('Parent',panelParameters,'Style','text',...
    'String','(3) QCL parameters',...
    'BackgroundColor',[.9 .9 .9],...    
    'ForegroundColor', [.1 .3 .5],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...
    'FontSize',16*font_scale,...
    'Units','pixels',...
    'Position',[0.01*XY(3) 0.49*XY(4) 0.15*XY(3) 0.025*XY(4)]);

% Popup menu: user can decide to calculate optimal QCL parameters or to
% enter the parameters manualy
Calc_type = uicontrol('Parent',panelParameters,'Style','popupmenu',...    
    'String',' Optimization | Enter manualy',...
    'Value',calc,...
    'BackgroundColor',[.9 .9 .9],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.045*XY(3) 0.45*XY(4) 0.09*XY(3) 0.025*XY(4)],...    
    'Callback',['calc = get(Calc_type,''Value'');', 'choose_calc'] );

QCLparam;

% Calculate optimal QCL parameters button
loadButParam = uicontrol('Parent',panelParameters,'Style','pushbutton',...    
    'Interruptible','on',...
    'String','Run',...
    'BackgroundColor',[.6 .2 .1],...    
    'ForegroundColor', 'w',...
    'FontWeight', 'bold', ...
    'FontSize',16*font_scale,...    
    'Position',[0.06*XY(3) 0.095*XY(4) 0.06*XY(3) 0.035*XY(4)],...
    'Callback', 'QCLparam_opt;');   

saveParamBut = uicontrol('parent',panelParameters,'Style','pushbutton',...    
    'UserData',0,...
    'String','Save',...
    'enable', 'inactive',...
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...    
    'FontWeight', 'bold',...    
    'FontSize',16*font_scale,...
    'Units','pixels',...
    'Position',[0.054*XY(3) 0.02*XY(4) 0.07*XY(3) 0.035*XY(4)],...
    'Callback','save_param;');
%%

% Range of magnetic field
panelMagField = uipanel('Title','Magnetic Field', 'foregroundcolor', [.1 .3 .5],...
    'BackgroundColor',[.9 .9 .9],...
    'TitlePosition','lefttop',...
    'FontWeight','bold',...
    'FontSize',20*font_scale,...
    'Units','pixels',...
    'Position',[0.7*XY(3) 0.598*XY(4) 0.13*XY(3) 0.23*XY(4)]);

% Bmin
textBmin = uicontrol('Parent',panelMagField,'Style','text',...
    'String','Bmin =',...
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.02*XY(3) 0.15*XY(4) 0.04*XY(3) 0.03*XY(4)]);   
editBmin = uicontrol('Parent',panelMagField,'Style','edit',...    
    'String',Bmin,...
    'enable','inactive',...
    'BackgroundColor','w',...
    'ForegroundColor',[.5 .5 .5],...
    'HorizontalAlignment','right',...    
    'FontWeight', 'bold',...        
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.06*XY(3) 0.155*XY(4) 0.04*XY(3) 0.025*XY(4)],...
    'Callback','change_Bmin;');
unitBmin = uicontrol('Parent',panelMagField,'Style','text',...
    'String','T',...
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...    
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.105*XY(3) 0.152*XY(4) 0.015*XY(3) 0.025*XY(4)]);
   
% Bmax
textBmax = uicontrol('Parent',panelMagField,'Style','text',...
    'String','Bmax =',...
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...    
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.02*XY(3) 0.112*XY(4) 0.04*XY(3) 0.03*XY(4)]); 
editBmax = uicontrol('Parent',panelMagField,'Style','edit',...    
    'String',Bmax,...
    'enable','inactive',...
    'BackgroundColor','w',...
    'ForegroundColor',[.5 .5 .5],...    
    'HorizontalAlignment','right',...
    'FontWeight', 'bold',...        
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.06*XY(3) 0.117*XY(4) 0.04*XY(3) 0.025*XY(4)],...
    'Callback','change_Bmax;');
unitBmax = uicontrol('Parent',panelMagField,'Style','text',...
    'String','T',...
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...    
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.105*XY(3) 0.114*XY(4) 0.015*XY(3) 0.025*XY(4)]);

% dB
textdB = uicontrol('Parent',panelMagField,'Style','text',...
    'String','dB =',...
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...    
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.034*XY(3) 0.073*XY(4) 0.03*XY(3) 0.03*XY(4)]); 
editdB = uicontrol('Parent',panelMagField,'Style','edit',...    
    'String',dB,...
    'enable','inactive',...    
    'BackgroundColor','w',...
    'ForegroundColor',[.5 .5 .5],...        
    'HorizontalAlignment','right',...
    'FontWeight', 'bold',...    
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.06*XY(3) 0.078*XY(4) 0.04*XY(3) 0.025*XY(4)],...
    'Callback','dB = str2double(get(editdB,''String''));');
unitdB = uicontrol('Parent',panelMagField,'Style','text',...
    'String','T',...    
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'HorizontalAlignment','left',...
    'FontWeight', 'bold',...
    'FontSize',15*font_scale,...
    'Units','pixels',...
    'Position',[0.105*XY(3) 0.073*XY(4) 0.015*XY(3) 0.025*XY(4)]);

% Calculate QCL characteristics in a magnetic field
loadButMF = uicontrol('Parent',panelMagField,'Style','pushbutton',...    
    'Interruptible','on',...
    'String','Run', ...
    'enable','inactive',... 
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'FontWeight', 'bold', ...    
    'FontSize',15*font_scale,...            
    'Position',[0.04*XY(3) 0.02*XY(4) 0.06*XY(3) 0.035*XY(4)],...
    'Callback',['main1;' 'main2; plot_on']);
%%

% Position of the figure in the main window
panelFigure = uipanel('BackgroundColor',[.9 .9 .9],...
    'TitlePosition','centertop',...
    'FontWeight','bold',...
    'Units','pixels',...
    'Position',[0.2*XY(3) 0.03*XY(4) 0.485*XY(3) 0.785*XY(4)]);
% At the beginning of the program, program will plot default results
plot_init;
%%

% Plot buttons
panelPlot = uipanel('Title','Plot results',...     
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor', [.1 .3 .5],...
    'TitlePosition','lefttop',...
    'FontWeight','bold',...
    'FontSize',20*font_scale,...
    'Units','pixels',...
    'Position',[0.7*XY(3) 0.14*XY(4) 0.13*XY(3) 0.42*XY(4)]);
plotWave = uicontrol('parent',panelPlot,'Style','pushbutton',...    
    'UserData',0,...
    'String','Wave func.',...
    'enable', 'inactive',...    
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'FontWeight', 'bold',...
    'FontSize',16*font_scale,...
    'Units','pixels',...
    'Position',[0.03*XY(3) 0.34*XY(4) 0.07*XY(3) 0.035*XY(4)],...
    'Callback','plotU;');
plotRelaxRate = uicontrol('parent',panelPlot,'Style','pushbutton',...    
    'UserData',0,...    
    'String','Relaxation',...
    'enable', 'inactive',...    
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'FontWeight', 'bold',...
    'FontSize',16*font_scale,...
    'Units','pixels',...
    'Position',[0.03*XY(3) 0.28*XY(4) 0.07*XY(3) 0.035*XY(4)],...
    'Callback','plotTau;');
plotPopInv = uicontrol('parent',panelPlot,'Style','pushbutton',...    
    'UserData',0,...    
    'String','Densities',...
    'enable', 'inactive',...
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'FontWeight', 'bold',...
    'FontSize',16*font_scale,...
    'Units','pixels',...
    'Position',[0.03*XY(3) 0.22*XY(4) 0.07*XY(3) 0.035*XY(4)],...
    'Callback','plotN;');
plotGain = uicontrol('parent',panelPlot,'Style','pushbutton',...    
    'UserData',0,...    
    'String','Gain',...
    'enable', 'inactive',...
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'FontWeight', 'bold',...
    'FontSize',16*font_scale,...
    'Units','pixels',...
    'Position',[0.03*XY(3) 0.16*XY(4) 0.07*XY(3) 0.035*XY(4)],...
    'Callback','plotG;');
plotAll = uicontrol('parent',panelPlot,'Style','pushbutton',...    
    'UserData',0,...    
    'String','Plot all',...
    'enable', 'inactive',...
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'FontWeight', 'bold',...
    'FontSize',16*font_scale,...
    'Units','pixels',...
    'Position',[0.03*XY(3) 0.1*XY(4) 0.07*XY(3) 0.035*XY(4)],...
    'Callback','plot_all;');

saveFigBut = uicontrol('parent',panelPlot,'Style','pushbutton',...    
    'UserData',0,...    
    'String','Save',...
    'enable', 'inactive',...
    'BackgroundColor',[.9 .9 .9],...
    'ForegroundColor',[.5 .5 .5],...
    'FontWeight', 'bold',...
    'FontSize',16*font_scale,...
    'Units','pixels',...
    'Position',[0.03*XY(3) 0.02*XY(4) 0.07*XY(3) 0.035*XY(4)],...
    'Callback','save_fig;');
%%

% Close main window and exit the program
closeBut = uicontrol('Style','pushbutton',...    
    'String','Close',...    
    'BackgroundColor', [.9 .9 .9],...
    'ForegroundColor', [.1 .3 .5],...
    'FontWeight', 'bold',...
    'FontSize',16*font_scale,...
    'Position',[0.732*XY(3) 0.05*XY(4) 0.072*XY(3) 0.04*XY(4)],...
    'Callback','close all;');
