% Callback function for "Optimization" option from popup menu. When user
% chose "Optimization", optimal QCL parameters for given wavelength will be
% calculated using simulated annealing algorithm.
% Simulated annealing is a global optimization method that distinguishes
% between different local optima. Starting from an initial point, the
% algorithm takes a step and the function is evaluated. When minimizing a
% function, any downhill step is accepted and the process repeats from this
% new point. An uphill step may be accepted. Thus, it can escape from local
% optima. This uphill decision is made by the Metropolis criteria. As the
% optimization process proceeds, the length of the steps decline and the
% algorithm closes in on the global optimum. Since the algorithm makes very
% few assumptions regarding the function to be optimized, it is quite
% robust with respect to non-quadratic surfaces. The degree of robustness
% can be adjusted by the user. In fact, simulated annealing can be used as
% a local optimizer for difficult functions.

loss = @(p)fitness_fun(p(1), p(2), p(3), p(4), p(5), p(6), p(7));
% parent  = [0.2 40e5 20 20 20 20 20];
parent  = [0.33 44e5 19 11 58 11 49];
[x f] = anneal(loss, parent);
x(3:7) = x(3:7) .* (x(3:7)>1);

X = x(1);
K = x(2);
zw0 = x(3);
zb1 = x(4);
zw1 = x(5);
zb2 = x(6);
zw2 = x(7);

main1

% Add results of calculated variables to appropriate fields
set (editX,'enable','inactive','BackgroundColor',[1 1 1],'ForegroundColor',[0 0 0],'String',num2str(round(X*100)/100));
set (editK,'enable','inactive','BackgroundColor',[1 1 1],'ForegroundColor',[0 0 0],'String',num2str(round(K*1e-3)));
set (editZ1,'enable','inactive','BackgroundColor',[1 1 1],'ForegroundColor',[0 0 0],'String',num2str(round(zw0)));
set (editZ2,'enable','inactive','BackgroundColor',[1 1 1],'ForegroundColor',[0 0 0],'String',num2str(round(zb1)));
set (editZ3,'enable','inactive','BackgroundColor',[1 1 1],'ForegroundColor',[0 0 0],'String',num2str(round(zw1)));
set (editZ4,'enable','inactive','BackgroundColor',[1 1 1],'ForegroundColor',[0 0 0],'String',num2str(round(zb2)));
set (editZ5,'enable','inactive','BackgroundColor',[1 1 1],'ForegroundColor',[0 0 0],'String',num2str(round(zw2)));

% When optimal parameters are calculated, update main window
set (editlambda,'enable','inactive');
set (editT,'enable','inactive');
set (editDELTA,'enable','inactive');
set (editLAMBDA,'enable','inactive');
set (editBmin,'enable','on','BackgroundColor',[1 1 1],'ForegroundColor',[0 0 0]);
set (editdB,'enable','on','BackgroundColor',[1 1 1],'ForegroundColor',[0 0 0]);
set (editBmax,'enable','on','BackgroundColor',[1 1 1],'ForegroundColor',[0 0 0]);

set (textX,'ForegroundColor',[0 0 0]);
set (textK,'ForegroundColor',[0 0 0]);
set (textZ1,'ForegroundColor',[0 0 0]);
set (textZ2,'ForegroundColor',[0 0 0]);
set (textZ3,'ForegroundColor',[0 0 0]);
set (textZ4,'ForegroundColor',[0 0 0]);
set (textZ5,'ForegroundColor',[0 0 0]);
set (textBmin,'ForegroundColor',[0 0 0]);
set (textdB,'ForegroundColor',[0 0 0]);
set (textBmax,'ForegroundColor',[0 0 0]);

set (unitK,'ForegroundColor',[0 0 0]);
set (unitZ1,'ForegroundColor',[0 0 0]);
set (unitZ2,'ForegroundColor',[0 0 0]);
set (unitZ3,'ForegroundColor',[0 0 0]);
set (unitZ4,'ForegroundColor',[0 0 0]);
set (unitZ5,'ForegroundColor',[0 0 0]);
set (unitBmin,'ForegroundColor',[0 0 0]);
set (unitdB,'ForegroundColor',[0 0 0]);
set (unitBmax,'ForegroundColor',[0 0 0]);

set(loadButParam,'enable','inactive','BackgroundColor',[.9 .9 .9],'ForegroundColor', [.5 .5 .5]);
set(saveParamBut,'enable','on','BackgroundColor',[.9 .9 .9], 'ForegroundColor', 'k');
set(loadButMF,'enable','on','BackgroundColor',[.6 .2 .1], 'ForegroundColor', 'w');

set(plotWave,'enable','on','BackgroundColor',[.9 .9 .9], 'foregroundcolor', 'k');
set(saveFigBut,'enable','on','BackgroundColor',[.9 .9 .9], 'foregroundcolor', 'k');
