function W = WIR_opt(En2, En1, F21, DELTA, LAMBDA, delta, m)
% Interface Roughness Scattering rate between levels n2 and n1
    
    global e hbar Angstrom NIRcut NIRstep
    
    scalingFact = 1 / Angstrom ^ 2 / e;
    
    % Relative boundary and time step size for x
    xcut = NIRcut / sqrt(hbar ^ 4 / 4 / m ^ 2 / 2 / delta ^ 2 * scalingFact ^ 2); % 1/A^2
    dx = xcut / NIRstep; % A
    x = 0 : dx : xcut;

    % Relative boundary and time step size for theta
    dtheta = pi / 2 / NIRstep; % A
    theta = 0 : dtheta : pi / 2;
          
    % Simpson numerical integration for x and theta
    % -------------------------------------------------------------
    % simpson1D -> odd number
    if (rem(length(x), 2) == 0)
        x = x(1 : end - 1);
        % new time step size for x
        dx = (x(end) - x(1)) / (length(x) -  1);
    end
    % simpson 1D
    sim1d1 = ones(1, length(x));
    sim1d1 = 4 * (rem(find(sim1d1), 2) == 0) + 2 * (rem(find(sim1d1), 2) == 1);
    sim1d1(1) = 1;
    sim1d1(end) = 1;
    % simpson1D -> odd number
    if (rem(length(theta), 2) == 0)
        theta = theta(1 : end - 1);
        % new time step size for theta
        dtheta = (theta(end) - theta(1)) / (length(theta) -  1);
    end
    % simpson 1D
    sim1d2 = ones(1, length(theta));
    sim1d2 = 4 * (rem(find(sim1d2), 2) == 0) + 2 * (rem(find(sim1d2), 2) == 1);
    sim1d2(1) = 1;
    sim1d2(end) = 1;
    % simpson 2D
    [sim2d1, sim2d2] = meshgrid(sim1d1, sim1d2);
    sim2d = sim2d1 .* sim2d2;
    % -------------------------------------------------------------

    % 2D meshgrid
    [x, theta] = meshgrid(x, theta);

    
    I = 0.5 * sum(sum(sim2d .* ...
        exp(- ((En2 - En1) ^ 2 / (2 * delta ^ 2)) - (hbar ^ 4 / 4 / m ^ 2 * x.* x * scalingFact ^ 2) / (2 * delta ^ 2) - ...
        (LAMBDA ^ 2 / 4 - (hbar ^ 2 / m * (En2 - En1) * scalingFact) / (2 * delta ^ 2))  .* x)));

    I = I * dx * dtheta / 9;
    
    W = 2 * pi / hbar / delta / sqrt(2 * pi) / pi * sum(abs(F21) .^ 2) * DELTA ^ 2 * LAMBDA ^ 2 * I;

    W = 1 / (W * e); % 1 / s

end
