function [U0, Egw, Egb] = enrggap(x2, TEMP)
% Calculating energy gap

% Calculating difference dEc_Gamma = abs(Ec_Gamma1 - Ec_Gamma2) for GaAs
% and Al(0.33)Ga(0.67)As

global STEP
STEP =0.01;

% Number of steps

N = length(0 : STEP : 1);

% Number of combinations of different compounds

M = 1;

% Binary compounds

global BINARY

BINARY = 1;

% GaAs = 1;
% AlAs = 2;
% InAs = 3;
% GaP = 4;
% AlP = 5;
% InP = 6;
% GaSb = 7;
% AlSb = 8;
% InSb = 9;

% Valence band offset for binary compounds in relation to the InSb

Ev = [-0.8 -1.33 -0.59 -1.27 -1.74 -0.94 -0.03 -0.41 0]; % eV, [1], [2]

% Gamma parameters of corresponding binary compounds

Eg_Gamma_0K = [1.519 3.099 0.417 2.886 3.63 1.4236 0.812 2.386 0.235]; % eV, (0 K), [1], [2]
alpha_Gama = [0.5405 0.885 0.276 0 0.5771 0.363 0.417 0.42 0.32] * 1e-3; % eV/K, [1], [2]
beta_Gamma = [204 530 93 0 372 162 140 140 170]; % K

Eg_Gamma = Eg_Gamma_0K - alpha_Gama * TEMP * TEMP ./ (TEMP + beta_Gamma); % eV, [1], [2]
Eg_Gamma(4) = Eg_Gamma_0K(4) + 0.1081 * (1 - coth(164 / TEMP)); % temperature correction for GaP, [1]

ac_Gamma = [-7.17 -5.64 -5.08 -8.2 -5.7 -6.0 -7.5 -4.5 -6.94]; %eV, [1], [2]

% X parameters of corresponding binary compounds

Eg_X_0K = [1.981 2.24 1.433 2.35 2.52 2.384 1.141 1.696 0.63]; % eV, (0 K), [1], [2]
alpha_X = [0.46 0.7 0.276 0.5771 0.318 0 0.475 0.39 0] * 1e-3; % eV/K, [1], [2]
beta_X = [204 530 93 372 588 0 94 140 0]; % K

Eg_X = Eg_X_0K - alpha_X * TEMP * TEMP ./ (TEMP + beta_X); % eV, [1], [2]
Eg_X(6) = Eg_Gamma_0K(6) - 3.7 * 1e-4 * TEMP; % temperature correction for InP, [1]

E1_X = [1.05 1.2 1.59 2.7 1.81 1.85 1.99 0 1.56]; % eV, [3]
E2_X = [6.5 6.9 3.7 6.3 6.75 3.3 6.46 5.4 4.53]; % eV, [3]

ac_X = E1_X; % [3], [4]

% Lattice constants for binary compounds

a = [5.65325 5.6611 6.0583 5.4505 5.4672 5.8697 6.0959 6.1355 6.4794]; % Angstrom = 0.1 nm, [1], [2]

% Elastic constants of binary compounds

c11 = [1221 1250 832.9 1405 1330 1011 884.2 876.9 684.7]; % GPa, [1], [2]
c12 = [566 534 452.6 620.3 630 561 402.6 434.1 373.5]; % GPa, [1], [2]

% Ternary alloys in two forms: ABxC(1-x) and AxB(1-x)C

global TERNARY TER

TERNARY = 2;

TER(1, :) = [1 4]; % GaAsP
TER(2, :) = [1 7]; % GaAsSb
TER(3, :) = [4 7]; % GaPSb
TER(4, :) = [2 5]; % AlAsP
TER(5, :) = [2 8]; % AlAsSb
TER(6, :) = [5 8]; % AlPSb
TER(7, :) = [3 6]; % InAsP
TER(8, :) = [3 9]; % InAsSb
TER(9, :) = [6 9]; % InPSb

TER(10, :) = [2 1]; % AlGaAs
TER(11, :) = [2 3]; % AlInAs
TER(12, :) = [1 3]; % GaInAs
TER(13, :) = [5 4]; % AlGaP
TER(14, :) = [5 6]; % AlInP
TER(15, :) = [4 6]; % GaInP
TER(16, :) = [8 7]; % AlGaSb
TER(17, :) = [8 9]; % AlInSb
TER(18, :) = [7 9]; % GaInSb

% bowing parameters of the valence band offset, eV, [1]

bow_Ev = zeros(18, 2);
bow_Ev(2, 2) = -1.06;
bow_Ev(5, 2) = -1.71;
bow_Ev(11, 2) = -0.64;
bow_Ev(12, 2) = -0.38;

% bowing parameters of Gamma energy gaps, eV, [1], [2]

bow_Eg_Gamma(1, :) = [0 0.19];
bow_Eg_Gamma(2, :) = [0 1.43];
bow_Eg_Gamma(3, :) = [0 2.7];
bow_Eg_Gamma(4, :) = [0 0.22];
bow_Eg_Gamma(5, :) = [0 0.8];
bow_Eg_Gamma(6, :) = [0 2.7];
bow_Eg_Gamma(7, :) = [0 0.1];
bow_Eg_Gamma(8, :) = [0 0.67];
bow_Eg_Gamma(9, :) = [0 1.9];

bow_Eg_Gamma(10, :) = [1.31 -0.127];
bow_Eg_Gamma(11, :) = [0 0.7];
bow_Eg_Gamma(12, :) = [0 0.477];
bow_Eg_Gamma(13, :) = [0 0];
bow_Eg_Gamma(14, :) = [0 -0.48];
bow_Eg_Gamma(15, :) = [0 0.65];
bow_Eg_Gamma(16, :) = [1.22 -0.044];
bow_Eg_Gamma(17, :) = [0 0.43];
bow_Eg_Gamma(18, :) = [0 0.415];

% bowing parameters of X energy gaps, eV, [1], [2]

bow_Eg_X(1, :) = [0 0.24];
bow_Eg_X(2, :) = [0 1.2];
bow_Eg_X(3, :) = [0 2.7];
bow_Eg_X(4, :) = [0 0.22];
bow_Eg_X(5, :) = [0 0.28];
bow_Eg_X(6, :) = [0 2.7];
bow_Eg_X(7, :) = [0 0.27];
bow_Eg_X(8, :) = [0 0.6];
bow_Eg_X(9, :) = [0 1.9];

bow_Eg_X(10, :) = [0 0.055];
bow_Eg_X(11, :) = [0 0];
bow_Eg_X(12, :) = [0 1.4];
bow_Eg_X(13, :) = [0 0.13];
bow_Eg_X(14, :) = [0 0.38];
bow_Eg_X(15, :) = [0 0.2];
bow_Eg_X(16, :) = [0 0];
bow_Eg_X(17, :) = [0 0];
bow_Eg_X(18, :) = [0 0.33];

% Hydrostatic deformation potential bowing parameters of the gamma conduction-band, eV, [1]

bow_ac_Gamma = zeros(18, 2);
bow_ac_Gamma(11, 2) = -1.4;
bow_ac_Gamma(12, 2) = 2.61;

% Shear deformation potential bowing parameters of the X conduction-band are zero, [1], [3]

bow_ac_X = zeros(18, 2);
bow_E2_X = zeros(18, 2);

% bowing parameters of a, c11 and c12 are zero, [1]

bow_a = zeros(18, 2);
bow_c11 = zeros(18, 2);
bow_c12 = zeros(18, 2);

% Processing ...

dEc_Gamma = -ones(1, M);

mat1 = zeros(M, 2);
mat2 = zeros(M, 2);

Ev1Ec_Gamma1Ec_X1 = zeros(M, 4);
Ev2Ec_Gamma2Ec_X2 = zeros(M, 4);

x1y1z1 = -ones(M, 3);
x2y2z2 = -ones(M, 3);

counter = 0;

% Material 1 is BIN, material 2 is TER

i = 1;
j = 10;
        
counter = counter + 1;
        
mat1(counter, :) = [BINARY i];
mat2(counter, :) = [TERNARY j];
        
% 1. BIN material
        
Ev1 = Ev(i);
        
Eg_Gamma1 = Eg_Gamma(i);
Ec_Gamma1 = Ev1 + Eg_Gamma1;
ac_Gamma1 = ac_Gamma(i);
        
E2_X1 = E2_X(i);
        
Eg_X1 = Eg_X(i);
Ec_X1 = Ev1 + Eg_X1;
ac_X1 = ac_X(i);
        
a1 = a(i);
c11_1 = c11(i);
c12_1 = c12(i);
        
% 2. TER material
        
Ev2 = ter(Ev, j, x2, bow_Ev);
        
Eg_Gamma2 = ter(Eg_Gamma, j, x2, bow_Eg_Gamma);
Ec_Gamma2 = Ev2 + Eg_Gamma2;
ac_Gamma2 = ter(ac_Gamma, j, x2, bow_ac_Gamma);
        
E2_X2 = ter(E2_X, j, x2, bow_E2_X);
        
Eg_X2 = ter(Eg_X, j, x2, bow_Eg_X);
Ec_X2 = Ev2 + Eg_X2;
ac_X2 = ter(ac_X, j, x2, bow_ac_X);
                
a2 = ter(a, j, x2, bow_a);
c11_2 = ter(c11, j, x2, bow_c11);
c12_2 = ter(c12, j, x2, bow_c12);
        
% Algorithm ----
        
    StrainIn1 = (Ec_Gamma1 < Ec_Gamma2);
    StrainIn2 = (Ec_Gamma1 > Ec_Gamma2);
            
    eps1 = (a2 - a1) ./ a1; eps1 = eps1 .* StrainIn1;
    eps2 = (a1 - a2) ./ a2; eps2 = eps2 .* StrainIn2;
            
    Ec_Gamma1 = Ec_Gamma1 + 2 .* ac_Gamma1 .* eps1 .* (1 - c12_1 ./ c11_1);        
    Ec_Gamma2 = Ec_Gamma2 + 2 .* ac_Gamma2 .* eps2 .* (1 - c12_2 ./ c11_2);
        
    dEc_X1 = - 2 / 3 * E2_X1 .* eps1 .* (1 + 2 * c12_1 ./c11_1);
    dEc_X2 = - 2 / 3 * E2_X2 .* eps2 .* (1 + 2 * c12_2 ./c11_2);
        
    Ec_X1 = Ec_X1 + 2 .* ac_X1 .* eps1 .* (1 - c12_1 ./ c11_1) + min(dEc_X1, - 1 / 2 * dEc_X1);        
    Ec_X2 = Ec_X2 + 2 .* ac_X2 .* eps2 .* (1 - c12_2 ./ c11_2) + min(dEc_X2, - 1 / 2 * dEc_X2);
    
    NoBrokenGap_Gamma = (Ec_Gamma2 > Ev1) & (Ec_Gamma1 > Ev2);
    NoBrokenGap_X = (Ec_X2 > Ev1) & (Ec_X1 > Ev2);
        
    direct = min(Ec_X1, Ec_X2) > max(Ec_Gamma1, Ec_Gamma2);
            
    correct = NoBrokenGap_Gamma & NoBrokenGap_X & direct & ...
            ((StrainIn1 & (abs(eps1) <= 0.07)) | (StrainIn2 & (abs(eps2) <= 0.07)));
            
% --------------
        
if (find(correct, 1))
    [dEc_Gamma(counter), index] = max(abs(correct .* (Ec_Gamma1 - Ec_Gamma2)));
            
    Ev1Ec_Gamma1Ec_X1(counter, :) = [Ev1 Ec_Gamma1(index) Ec_X1(index) ...
                                        (Ec_X1(index) + 3 / 2 * abs(dEc_X1(index)))];
    Ev2Ec_Gamma2Ec_X2(counter, :) = [Ev2(index) Ec_Gamma2(index) Ec_X2(index) ...
                                        (Ec_X2(index) + 3 / 2 * abs(dEc_X2(index)))];
            
    x2y2z2(counter, 1) = x2(index); 
end

if (counter ~= M)
    disp('Error!')   
end

counter = 0;

for i = 1 : M
    if ((dEc_Gamma(i) > 0) && noendpoints(x1y1z1(i, :)) && noendpoints(x2y2z2(i, :)))      
        counter = counter + 1;
        
        U0 = dEc_Gamma;
        Egw = Ev1Ec_Gamma1Ec_X1(i, 2) - Ev1Ec_Gamma1Ec_X1(i, 1);
        Egb = Ev2Ec_Gamma2Ec_X2(i, 2) - Ev2Ec_Gamma2Ec_X2(i, 1);
    end
end

end

