% Callback function for "Wave func.". When user clicks "Wave func.", 
% the program will plot the subband positions at zero magnetic fields, 
% together with the coresponding wave functions squared.

z = dlmread('z.txt',',');
U = dlmread('U.txt',',');
fid = fopen('enrgwave.txt','r');
Nn = fscanf(fid, '%d', 1);
Nz = fscanf(fid, '%d', 1);
En = zeros(1, Nn);

for i = 1 : Nn
    En(i) = fscanf(fid, '%f', 1);
end
eta = zeros(Nn, Nz);
for j = 1 : Nz
    for i = 1 : Nn
        eta(i, j) = fscanf(fid, '%f', 1);
    end
end
fclose(fid);

hold off
subplot(1,1,1,'Parent',panelFigure)
plot(z, U,'linewidth',font_scale*4)
xlabel(['z [',197,']'],'FontSize',font_scale*20)
ylabel('U [eV]','FontSize',font_scale*20)
title('Conduction band diagram. Wave functions','FontWeight','bold','FontSize',font_scale*20)
hold on

for i = 1 : 3
    plot( z(1 : floor(end / 100) : end), En(i), 'b--','linewidth',font_scale*4)
    text(z(1), En(i), ['\color{blue}', '{\itE}_{', int2str(i), '}'], 'HorizontalAlignment','right','FontSize',font_scale*20)
    plot(z, En(i) + eta(i, :) .* eta(i, :), 'r','linewidth',font_scale*4)
end

xlim([-200 200])
set(gca,'FontSize',font_scale*20)