function save_fig_all
% Save all graphics

% Fig1. The subband positions at zero magnetic fields, together with the
% coresponding wave functions squared
% ------------------------------------------------------------------------- 
z = dlmread('z.txt',',');
U = dlmread('U.txt',',');
fid = fopen('enrgwave.txt','r');
Nn = fscanf(fid, '%d', 1);
Nz = fscanf(fid, '%d', 1);
En = zeros(1, Nn);
for i = 1 : Nn
En(i) = fscanf(fid, '%f', 1);
end
eta = zeros(Nn, Nz);
for j = 1 : Nz
for i = 1 : Nn
    eta(i, j) = fscanf(fid, '%f', 1);
end
end
fclose(fid);
hold off
hF1 = figure(2);
set(hF1,'Visible','off')
plot(z, U,'linewidth',2)
xlabel(['z [',197,']'])
ylabel('U [eV]')
title('Conduction band diagram. Wave functions','FontWeight','bold')
hold on
for i = 1 : 3
plot( z(1 : floor(end / 100) : end), En(i), 'b--','linewidth',2)
text(z(1), En(i), ['\color{blue}', '{\itE}_{', int2str(i), '}'], 'HorizontalAlignment','right')
plot(z, En(i) + eta(i, :) .* eta(i, :), 'r','linewidth',2)
end

% load results from file 'res.txt'
% -------------------------------------------------------------------------
fid = fopen('res.txt','r');
NB = fscanf(fid, '%d', 1);
Bmin = fscanf(fid, '%f', 1);
dB = fscanf(fid, '%f', 1);
Bmax = fscanf(fid, '%f', 1);
TEMP = fscanf(fid, '%f', 1);
B = zeros(1, NB);
W30lo = zeros(1, NB);
W30ir = zeros(1, NB);
W30loir = zeros(1, NB);
N20lo = zeros(1, NB);
N30lo = zeros(1, NB);
N20loir = zeros(1, NB);
N30loir = zeros(1, NB);
g32lo = zeros(1, NB);
g32loir = zeros(1, NB);
for i = 1 : NB
B(i) = fscanf(fid, '%f ', 1);
W30lo(i) = fscanf(fid, '%f', 1);
W30ir(i) = fscanf(fid, '%f', 1);
W30loir(i) = fscanf(fid, '%f', 1);
N20lo(i) = fscanf(fid, '%f', 1);
N30lo(i) = fscanf(fid, '%f', 1);
N20loir(i) = fscanf(fid, '%f', 1);
N30loir(i) = fscanf(fid, '%f', 1);
g32lo(i) = fscanf(fid, '%f', 1);
g32loir(i) = fscanf(fid, '%f', 1);
end
fclose(fid);
% -------------------------------------------------------------------------


% Fig2. The total electron relaxation rate for transitions from (3, 0) subband 
% into the (2, l) and (1, l) subbands
% -------------------------------------------------------------------------
hF2 = figure(3);
set(hF2,'Visible','off')
plot(B, W30lo, '--', B, W30ir, '-.', B, W30loir,'linewidth',2)
xlabel('B [T]')
ylabel('1 / \tau_{3,0} [1/ps]')
title('Relaxation rate','FontWeight','bold')
h = legend('1/\tau_{\rm LO}', '1/\tau_{\rm IR}', '1/\tau_{\rm LO} + 1/\tau_{\rm IR}', 'Location', 'Best');
set(h, 'Box', 'off')

% Fig3. The ratio of the total electron areal densities in the ground laser
% levels of the third and the second subband
% -------------------------------------------------------------------------
hF3 = figure(4);
set(hF3,'Visible','off')
plot(B, N30lo ./ N20lo, 'b--', B, N30loir ./ N20loir, 'r','linewidth',3)
title('Population inversion','FontWeight','bold')
xlabel('B [T]')
ylabel('N_{3,0} / N_{2,0}')
h = legend('1/\tau_{\rm LO}', '1/\tau_{\rm LO} + 1/\tau_{\rm IR}', 'Location', 'Best');
set(h, 'Box', 'off')

% Fig4. QCL gain
% -------------------------------------------------------------------------
hF4 = figure(5);
set(hF4,'Visible','off')
plot(B, g32lo, 'b--', B, g32loir, 'r','linewidth',2)
title('The optical gain','FontWeight','bold')
xlabel('B [T]')
ylabel('g [{cm}^2 / {kA}]')
h = legend('1/\tau_{\rm LO}', '1/\tau_{\rm LO} + 1/\tau_{\rm IR}', 'Location', 'Best');
set(h, 'Box', 'off')

[fname,pname] = uiputfile('*.tif','Save figure');
if(fname~=0)
fname = fname(1:end-4);
fpname1 = strcat(pname,fname,'_WaveFunc.tif');
fpname2 = strcat(pname,fname,'_Relaxation.tif');
fpname3 = strcat(pname,fname,'_Densities.tif');
fpname4 = strcat(pname,fname,'_Gain.tif');
if exist(fpname1,'file')
    delete(fpname1);
end    
if exist(fpname2,'file')
    delete(fpname2);
end    
if exist(fpname3,'file')
    delete(fpname3);
end    
if exist(fpname4,'file')
    delete(fpname4);
end    
set(hF1,'PaperPositionMode','auto','InvertHardcopy','off')
print(hF1,'-dtiff','-r300',fpname1);
set(hF2,'PaperPositionMode','auto','InvertHardcopy','off')
print(hF2,'-dtiff','-r300',fpname2);
set(hF3,'PaperPositionMode','auto','InvertHardcopy','off')
print(hF3,'-dtiff','-r300',fpname3);
set(hF4,'PaperPositionMode','auto','InvertHardcopy','off')
print(hF4,'-dtiff','-r300',fpname4);
end

close(2)
close(3)
close(4)
close(5)

end
